@@ -32,6 +32,9 @@ else:
     from urllib.parse import quote, quote_plus, urlencode, urlparse
     from urllib.parse import urlsplit
 
+    long = int
+    unicode = str
+
     def u(x):
         return x
 
@@ -123,7 +126,7 @@ def build_path(*args):
     # don't include segment if it's None
     # quote_plus doesn't work for neo4j index lookups 
     # e.g., index/node/test_idxV/name/James+Thornton
-    segments = [quote(str(segment), safe='') for segment in args if segment is not None]
+    segments = [quote(unicode(segment), safe='') for segment in args if segment is not None]
     path = "/".join(segments)
     return path
 
